@@ -128,183 +128,267 @@ The result dumped is following:
     $VAR1 = {
         'span' => {
             '-class' => 'author',
-            '#text' => 'Kawasaki Yusuke'
+            '#text'  => 'Kawasaki Yusuke'
         }
     };
 
 The special node name of C<#text> is used because this elements
 has attribute(s) in addition to the text node.
+See also L</text_node_key> option.
 
 =head1 METHODS
 
-=head2 $tpp = XML::TreePP->new( %options );
+=head2 new
 
 This constructor method returns a new XML::TreePP object with C<%options>.
 
-=head2 $tpp->set( option_name => $option_value );
+    $tpp = XML::TreePP->new( %options );
+
+=head2 set
 
 This method sets a option value for C<option_name>.
 If C<$option_value> is not defined, its option is deleted.
-See L</OPTIONS> section below.
 
-=head2 $tpp->get( 'option_name' );
+    $tpp->set( option_name => $option_value );
+
+See L</OPTIONS> section for details.
+
+=head2 get
 
 This method returns a current option value for C<option_name>.
 
-=head2 $tree = $tpp->parse( $source );
+    $tpp->get( 'option_name' );
+
+=head2 parse
 
 This method reads XML source and returns a hash tree converted.
 The first argument is a scalar or a reference to a scalar.
 
-=head2 $tree = $tpp->parsefile( $file );
+        $tree = $tpp->parse( $source );
+
+=head2 parsefile
 
 This method reads a XML file and returns a hash tree converted.
 The first argument is a filename.
 
-=head2 $tree = $tpp->parsehttp( $method, $url, $body, $head );
+    $tree = $tpp->parsefile( $file );
+
+=head2 parsehttp
 
 This method receives a XML file from a remote server via HTTP and
 returns a hash tree converted.
+
+    $tree = $tpp->parsehttp( $method, $url, $body, $head );
+
 C<$method> is a method of HTTP connection: GET/POST/PUT/DELETE
 C<$url> is an URI of a XML file.
 C<$body> is a request body when you use POST method.
 C<$head> is a request headers as a hash ref.
 L<LWP::UserAgent> module or L<HTTP::Lite> module is required to fetch a file.
 
-=head2 ( $tree, $xml, $code ) = $tpp->parsehttp( $method, $url, $body, $head );
+    ( $tree, $xml, $code ) = $tpp->parsehttp( $method, $url, $body, $head );
 
 In array context, This method returns also raw XML source received
 and HTTP response's status code.
 
-=head2 $source = $tpp->write( $tree, $encode );
+=head2 write
 
 This method parses a hash tree and returns a XML source generated.
-C<$tree> is a referecen to a hash tree.
 
-=head2 $tpp->writefile( $file, $tree, $encode );
+    $source = $tpp->write( $tree, $encode );
+
+C<$tree> is a reference to a hash tree.
+
+=head2 writefile
 
 This method parses a hash tree and writes a XML source into a file.
+
+    $tpp->writefile( $file, $tree, $encode );
+
 C<$file> is a filename to create.
-C<$tree> is a referecen to a hash tree.
+C<$tree> is a reference to a hash tree.
 
 =head1 OPTIONS
 
-=head2 $tpp->set( output_encoding => 'UTF-8' );
+This module accepts option parameters following:
 
-You can define a encoding of xml file generated by write/writefile
-methods. On Perl 5.8.x and later, you can select it from every
-encodings supported by Encode.pm. On Perl 5.6.x and before with
-Jcode.pm, you can use C<Shift_JIS>, C<EUC-JP>, C<ISO-2022-JP> and
-C<UTF-8>. The default value is C<UTF-8>.
+=head2 OPTIONS FOR PARSING XML
 
-=head2 $tpp->set( force_array => [ 'rdf:li', 'item', '-xmlns' ] );
+=head3 force_array
 
 This option allows you to specify a list of element names which
 should always be forced into an array representation.
+
+    $tpp->set( force_array => [ 'rdf:li', 'item', '-xmlns' ] );
+
 The default value is null, it means that context of the elements
 will determine to make array or to keep it scalar or hash.
 Note that the special wildcard name C<'*'> means all elements.
 
-=head2 $tpp->set( force_hash => [ 'item', 'image' ] );
+=head3 force_hash
 
 This option allows you to specify a list of element names which
 should always be forced into an hash representation.
+
+    $tpp->set( force_hash => [ 'item', 'image' ] );
+
 The default value is null, it means that context of the elements
 will determine to make hash or to keep it scalar as a text node.
-See also C<text_node_key> option below.
+See also L</text_node_key> option below.
 Note that the special wildcard name C<'*'> means all elements.
 
-=head2 $tpp->set( first_out => [ 'link', 'title', '-type' ] );
+=head3 cdata_scalar_ref
+
+This option allows you to convert a cdata section into a reference
+for scalar on parsing XML source.
+
+    $tpp->set( cdata_scalar_ref => 1 );
+
+The default value is false, it means that each cdata section is converted into a scalar.
+
+=head3 user_agent
+
+This option allows you to specify a HTTP_USER_AGENT string which
+is used by parsehttp() method.
+
+    $tpp->set( user_agent => 'Mozilla/4.0 (compatible; ...)' );
+
+The default string is C<'XML-TreePP/#.##'>, where C<'#.##'> is
+substituted with the version number of this library.
+
+=head3 http_lite
+
+This option forces pasrsehttp() method to use a L<HTTP::Lite> instance.
+
+    my $http = HTTP::Lite->new();
+    $tpp->set( http_lite => $http );
+
+=head3 lwp_useragent
+
+This option forces pasrsehttp() method to use a L<LWP::UserAgent> instance.
+
+    my $ua = LWP::UserAgent->new();
+    $ua->timeout( 60 );
+    $ua->env_proxy;
+    $tpp->set( lwp_useragent => $ua );
+
+You may use this with L<LWP::UserAgent::WithCache>.
+
+=head3 base_class
+
+This blesses class name for each element's hashref.
+Each class is named straight as a child class of it parent class.
+
+    $tpp->set( base_class => 'MyElement' );
+    my $xml  = '<root><parent><child key="val">text</child></parent></root>';
+    my $tree = $tpp->parse( $xml );
+    print ref $tree->{root}->{parent}->{child}, "\n";
+
+A hash for <child> element above is blessed to C<MyElement::root::parent::child>
+class. You may use this with L<Class::Accessor>.
+
+=head3 elem_class
+
+This blesses class name for each element's hashref.
+Each class is named horizontally under the direct child of C<MyElement>.
+
+    $tpp->set( base_class => 'MyElement' );
+    my $xml  = '<root><parent><child key="val">text</child></parent></root>';
+    my $tree = $tpp->parse( $xml );
+    print ref $tree->{root}->{parent}->{child}, "\n";
+
+A hash for <child> element above is blessed to C<MyElement::child> class.
+
+=head2 OPTIONS FOR WRITING XML
+
+=head3 first_out
 
 This option allows you to specify a list of element/attribute
 names which should always appears at first on output XML code.
+
+    $tpp->set( first_out => [ 'link', 'title', '-type' ] );
+
 The default value is null, it means alphabetical order is used.
 
-=head2 $tpp->set( last_out => [ 'items', 'item', 'entry' ] );
+=head3 last_out
 
 This option allows you to specify a list of element/attribute
 names which should always appears at last on output XML code.
 
-=head2 $tpp->set( cdata_scalar_ref => 1 );
+    $tpp->set( last_out => [ 'items', 'item', 'entry' ] );
 
-This option allows you to convert a cdata section into a reference
-for scalar on parsing XML source. If this option is false, per
-default, cdata section is converted into a scalar.
+=head3 indent
 
-=head2 $tpp->set( user_agent => 'Mozilla/4.0 (compatible; ...)' );
+This makes the output more human readable by indenting appropriately.
 
-This option allows you to specify a HTTP_USER_AGENT string which
-is used by parsehttp() method.
-The default string is C<'XML-TreePP/#.##'>, where C<'#.##'> is
-substituted with the version number of this library.
+    $tpp->set( indent => 2 );
 
-=head2 $tpp->set( attr_prefix => '@' );
+This doesn't strictly follow the XML Document Spec but does looks nice.
 
-This option allows you to specify a prefix character(s) which
-is inserted before each attribute names.
-The default character is C<'-'>.
-Or set C<'@'> to access attribute values like E4X, ECMAScript for XML.
-Zero-length prefix C<''> is also available now.
-
-=head2 $tpp->set( text_node_key => '#text' );
-
-This option allows you to specify a hash key for text nodes.
-The default key is C<#text>.
-
-=head2 $tpp->set( ignore_error => 1 );
-
-This module calls Carp::croak function on an error per default.
-This option makes all errors ignored and just return.
-
-=head2 $tpp->set( xml_decl => '' );
+=head3 xml_decl
 
 This module generates an XML declaration on writing an XML code per default.
 This option forces to change or leave it.
 
-=head2 $tpp->set( http_lite => $http );
+    $tpp->set( xml_decl => '' );
 
-This option forces pasrsehttp() method to use L<HTTP::Lite> module 
-with its instance created like: C<$http = HTTP::Lite-E<gt>new();>
+=head3 output_encoding
 
-=head2 $tpp->set( lwp_useragent => $ua );
+This option allows you to specify a encoding of xml file generated
+by write/writefile methods.
 
-This option forces pasrsehttp() method to use L<LWP::UserAgent> module 
-with its instance created like: C<$ua = LWP::UserAgent-E<gt>new();>
+    $tpp->set( output_encoding => 'UTF-8' );
 
-=head2 $tpp->set( use_ixhash => 1 );
+On Perl 5.8.x and later, you can select it from every
+encodings supported by Encode.pm. On Perl 5.6.x and before with
+Jcode.pm, you can use C<Shift_JIS>, C<EUC-JP>, C<ISO-2022-JP> and
+C<UTF-8>. The default value is C<UTF-8> which is recommended encoding.
 
-This option keeps the order for each element appeared in XML.
-L<Tie::IxHash> module is required.
-This makes parsing performance slow. (100% slower than default)
+=head2 OPTIONS FOR BOTH
 
-=head2 $tpp->set( indent => 2 );
-
-This makes the output more human readable by indenting appropriately.
-This doesn't strictly follow the XML Document Spec but does looks nice.
-
-=head2 $tpp->set( utf8_flag => 1 );
+=head3 utf8_flag
 
 This makes utf8 flag on for every element's value parsed
 and makes it on for an XML code generated as well.
 
-=head2 $tpp->set( base_class => 'MyElement' );
+    $tpp->set( utf8_flag => 1 );
 
-This declares (blesses) class name for each element's hashref.
-Each class is named straight as a child class of it parent class.
+Perl 5.8.x or later is required to use this.
 
-    <root><parent><child key="val">text</child></parent></root>
+=head3 attr_prefix
 
-E.g., <child> element above is blessed to C<MyElement::root::parent::child> 
-class. You may use this with L<Class::Accessor>.
+This option allows you to specify a prefix character(s) which
+is inserted before each attribute names.
 
-=head2 $tpp->set( elem_class => 'MyElement' );
+    $tpp->set( attr_prefix => '@' );
 
-This declares (blesses) class name for each element's hashref.
-Each class is named horizontally under the direct child of C<MyElement>.
+The default character is C<'-'>.
+Or set C<'@'> to access attribute values like E4X, ECMAScript for XML.
+Zero-length prefix C<''> is available as well, it means no prefix is added.
 
-    <root><parent><child key="val">text</child></parent></root>
+=head3 text_node_key
 
-E.g., <child> element above is blessed to C<MyElement::child> class.
+This option allows you to specify a hash key for text nodes.
+
+    $tpp->set( text_node_key => '#text' );
+
+The default key is C<#text>.
+
+=head3 ignore_error
+
+This module calls Carp::croak function on an error per default.
+This option makes all errors ignored and just return.
+
+    $tpp->set( ignore_error => 1 );
+
+=head3 use_ixhash
+
+This option keeps the order for each element appeared in XML.
+L<Tie::IxHash> module is required.
+
+    $tpp->set( use_ixhash => 1 );
+
+This makes parsing performance slow. (100% slower than default)
 
 =head1 AUTHOR
 
@@ -313,7 +397,7 @@ Yusuke Kawasaki, http://www.kawa.net/
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2006-2007 Yusuke Kawasaki. All rights reserved.
-This program is free software; you can redistribute it and/or 
+This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =cut
@@ -324,7 +408,7 @@ use Carp;
 use Symbol;
 
 use vars qw( $VERSION );
-$VERSION = '0.26';
+$VERSION = '0.27';
 
 my $XML_ENCODING      = 'UTF-8';
 my $INTERNAL_ENCODING = 'UTF-8';
@@ -651,7 +735,7 @@ sub parse {
     }
     elsif ( exists $self->{elem_class} && $self->{elem_class} ) {
         bless( $tree, $self->{elem_class} );
-    } 
+    }
 
     wantarray ? ( $tree, $$textref ) : $tree;
 }
@@ -813,7 +897,7 @@ sub flat_to_tree {
                 $escname =~ s/\W/_/sg;
                 my $elmclass = $self->{elem_class}.'::'.$escname;
                 bless( $elem, $elmclass );
-            } 
+            }
         }
         # next unless defined $elem;
         $tree->{$name} ||= [];
@@ -903,7 +987,7 @@ sub hash_to_xml {
                 push( @$out, $child );
             }
         }
-    
+
         foreach my $key ( @$attrkey ) {
             my $name = substr( $key, $prelen );
             my $val = &xml_escape( $hash->{$key} );
@@ -1016,7 +1100,7 @@ sub encode_from_to {
     my $from   = shift or return;
     my $to     = shift or return;
     return $to if ( uc($from) eq uc($to) );
-    &load_encode() if ( $] > 5.008 );
+    &load_encode() if ( $] >= 5.008 );
 
     unless ( defined $Encode::EUCJPMS::VERSION ) {
         $from = 'EUC-JP' if ( $from =~ /\beuc-?jp-?(win|ms)$/i );
